aws-status
==========

Helps you check AWS status as seen from the official status page http://status.aws.amazon.com/

Thanks
------

- a great article about packaging python apps: https://hynek.me/articles/sharing-your-labor-of-love-pypi-quick-and-dirty/
- one example of parsing AWS status feeds (in Python): https://github.com/rhartkopf/check_aws_status_feed/blob/master/check_aws_status_feed.py
- an other example (in Ruby): https://gist.github.com/ktheory/1604786
